@@ -11,11 +11,11 @@ PICTURE_FORMATS_DICT = {
 
 
 def get_datetime_object(item):
-    unparsedpubdate = item.find('pubDate').text
+    unparsed_pubdate = item.find('pubDate').text
     # Wed, 23 Oct 2019 15:03:33 +0200
 
     created_at = datetime.datetime.strptime(
-        unparsedpubdate, "%a, %d %b %Y %H:%M:%S {}".format(unparsedpubdate[-5:])).timetuple()
+        unparsed_pubdate, "%a, %d %b %Y %H:%M:%S {}".format(unparsed_pubdate[-5:])).timetuple()
     return datetime.datetime.fromtimestamp(time.mktime(created_at))
 
 
@@ -23,7 +23,7 @@ def get_medialink(item):
     return item.find('enclosure').attrib['url']
 
 
-def install_picture_content_wrap(picture_format, picture_formats, subdirectory, news_item, tempfolder):
+def install_picture_content_wrap(picture_format, picture_formats, subdirectory, news_item, temp_folder):
     # Installs content to LocalIntegratedContent folder and returns mediapath
     if not picture_format in picture_formats:
         return None
@@ -34,7 +34,7 @@ def install_picture_content_wrap(picture_format, picture_formats, subdirectory,
         media_link = media_link.replace('.jpg', '_sqr512.jpg')
 
     media_path = download_media(
-        PICTURE_FORMATS_DICT[picture_format] + media_link, subdirectory, tempfolder)
+        PICTURE_FORMATS_DICT[picture_format] + media_link, subdirectory, temp_folder)
 
     install_content(media_path, subdirectory)
 
